@@ -10,7 +10,6 @@ from contextlib import suppress
 from dataclasses import asdict
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar
-from warnings import warn
 
 from griffe import (
     AliasResolutionError,
@@ -22,15 +21,17 @@ from griffe import (
     patch_loggers,
 )
 from mkdocs.exceptions import PluginError
+from mkdocs_autorefs import BacklinkCrumb
 from mkdocstrings import BaseHandler, CollectionError, CollectorItem, HandlerOptions, Inventory, get_logger
 
 from mkdocstrings_handlers.python._internal import rendering
 from mkdocstrings_handlers.python._internal.config import PythonConfig, PythonOptions
 
 if TYPE_CHECKING:
-    from collections.abc import Iterator, Mapping, MutableMapping, Sequence
+    from collections.abc import Iterable, Iterator, Mapping, MutableMapping, Sequence
 
     from mkdocs.config.defaults import MkDocsConfig
+    from mkdocs_autorefs import Backlink
 
 
 # YORE: EOL 3.10: Replace block with line 2.
@@ -54,17 +55,6 @@ _logger = get_logger(__name__)
 patch_loggers(get_logger)
 
 
-# YORE: Bump 2: Remove block.
-def _warn_extra_options(names: Sequence[str]) -> None:
-    warn(
-        "Passing extra options directly under `options` is deprecated. "
-        "Instead, pass them under `options.extra`, and update your templates. "
-        f"Current extra (unrecognized) options: {', '.join(sorted(names))}",
-        DeprecationWarning,
-        stacklevel=3,
-    )
-
-
 class PythonHandler(BaseHandler):
     """The Python handler class."""
 
@@ -95,18 +85,9 @@ class PythonHandler(BaseHandler):
         self.base_dir = base_dir
         """The base directory of the project."""
 
-        # YORE: Bump 2: Remove block.
-        global_extra, global_options = PythonOptions._extract_extra(config.options)
-        if global_extra:
-            _warn_extra_options(global_extra.keys())  # type: ignore[arg-type]
-        self._global_extra = global_extra
-        self.global_options = global_options
+        self.global_options = config.options
         """The global configuration options (in `mkdocs.yml`)."""
 
-        # YORE: Bump 2: Replace `# ` with `` within block.
-        # self.global_options = config.options
-        # """The global configuration options (in `mkdocs.yml`)."""
-
         # Warn if user overrides base templates.
         if self.custom_templates:
             for theme_dir in base_dir.joinpath(self.custom_templates, "python").iterdir():
@@ -186,25 +167,13 @@ class PythonHandler(BaseHandler):
         Returns:
             The combined options.
         """
-        # YORE: Bump 2: Remove block.
-        local_extra, local_options = PythonOptions._extract_extra(local_options)  # type: ignore[arg-type]
-        if local_extra:
-            _warn_extra_options(local_extra.keys())  # type: ignore[arg-type]
-        unknown_extra = self._global_extra | local_extra
-
         extra = {**self.global_options.get("extra", {}), **local_options.get("extra", {})}
         options = {**self.global_options, **local_options, "extra": extra}
         try:
-            # YORE: Bump 2: Replace `opts =` with `return` within line.
-            opts = PythonOptions.from_data(**options)
+            return PythonOptions.from_data(**options)
         except Exception as error:
             raise PluginError(f"Invalid options: {error}") from error
 
-        # YORE: Bump 2: Remove block.
-        for key, value in unknown_extra.items():
-            object.__setattr__(opts, key, value)
-        return opts
-
     def collect(self, identifier: str, options: PythonOptions) -> CollectorItem:
         """Collect the documentation for the given identifier.
 
@@ -289,23 +258,40 @@ class PythonHandler(BaseHandler):
         Returns:
             The rendered data (HTML).
         """
-        template_name = rendering.do_get_template(self.env, data)
+        template_name = rendering.do_get_template(data)
         template = self.env.get_template(template_name)
 
         return template.render(
             **{
                 "config": options,
-                data.kind.value: data,
+                data.kind.value.replace(" ", "_"): data,
                 # Heading level is a "state" variable, that will change at each step
                 # of the rendering recursion. Therefore, it's easier to use it as a plain value
                 # than as an item in a dictionary.
                 "heading_level": options.heading_level,
                 "root": True,
-                # YORE: Bump 2: Regex-replace ` or .+` with ` or "en",` within line.
-                "locale": locale or self.config.locale,
+                "locale": locale or "en",
             },
         )
 
+    def render_backlinks(self, backlinks: Mapping[str, Iterable[Backlink]], *, locale: str | None = None) -> str:  # noqa: ARG002
+        """Render the backlinks.
+
+        Parameters:
+            backlinks: The backlinks to render.
+
+        Returns:
+            The rendered backlinks (HTML).
+        """
+        template = self.env.get_template("backlinks.html.jinja")
+        verbose_type = {key: key.capitalize().replace("-by", " by") for key in backlinks.keys()}  # noqa: SIM118
+        return template.render(
+            backlinks=backlinks,
+            config=self.get_options({}),
+            verbose_type=verbose_type,
+            default_crumb=BacklinkCrumb(title="", url=""),
+        )
+
     def update_env(self, config: Any) -> None:  # noqa: ARG002
         """Update the Jinja environment with custom filters and tests.
 
@@ -316,8 +302,6 @@ class PythonHandler(BaseHandler):
         self.env.lstrip_blocks = True
         self.env.keep_trailing_newline = False
         self.env.filters["split_path"] = rendering.do_split_path
-        self.env.filters["crossref"] = rendering.do_crossref
-        self.env.filters["multi_crossref"] = rendering.do_multi_crossref
         self.env.filters["order_members"] = rendering.do_order_members
         self.env.filters["format_code"] = rendering.do_format_code
         self.env.filters["format_signature"] = rendering.do_format_signature
@@ -414,10 +398,7 @@ def get_handler(
     # We therefore increase the limit here, once, before Griffe is used to collect or render stuff.
     sys.setrecursionlimit(max(sys.getrecursionlimit(), 2000))
 
-    base_dir = Path(tool_config.config_file_path or "./mkdocs.yml").parent
-    if "inventories" not in handler_config and "import" in handler_config:
-        warn("The 'import' key is renamed 'inventories' for the Python handler", FutureWarning, stacklevel=1)
-        handler_config["inventories"] = handler_config.pop("import", [])
+    base_dir = Path(getattr(tool_config, "config_file_path", None) or "./mkdocs.yml").parent
     return PythonHandler(
         config=PythonConfig.from_data(**handler_config),
         base_dir=base_dir,
